@@ -16,6 +16,7 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
+#include <ucommon/export.h>
 #include <ucommon/mapped.h>
 
 #ifdef  HAVE_FCNTL_H
@@ -29,6 +30,7 @@
 #endif
 
 #ifdef HAVE_SYS_MMAN_H
+#undef  __EXTENSIONS__
 #define __EXTENSIONS__
 #ifndef _POSIX_C_SOURCE
 #define _POSIX_C_SOURCE 200112L
