@@ -17,6 +17,7 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
+#include <ucommon/export.h>
 #include <ucommon/protocols.h>
 #include <ucommon/string.h>
 #include <stdlib.h>
@@ -56,6 +57,10 @@ void *MemoryProtocol::zalloc(size_t size)
     return mem;
 }
 
+MemoryProtocol::~MemoryProtocol()
+{
+}
+
 MemoryRedirect::MemoryRedirect(MemoryProtocol *protocol)
 {
     target = protocol;
@@ -419,3 +424,10 @@ void LockingProtocol::_unlock(void)
 {
 }
 
+LockingProtocol::~LockingProtocol()
+{
+}
+
+CharacterProtocol::~CharacterProtocol()
+{
+}
