@@ -254,12 +254,20 @@ public:
     private:
         const char *text;
 
-    public:
+    protected:
+        friend class stringpager;
+
+        inline void set(member *node)
+            {next = node;};
+
         member(LinkedObject **root, const char *data);
-        inline const char *operator*()
+        member(const char *data);
+
+    public:
+        inline const char *operator*() const
             {return text;};
 
-        inline const char *get(void)
+        inline const char *get(void) const
             {return text;};
     };
 
@@ -321,7 +329,7 @@ public:
         {return static_cast<stringpager::member *>(root);};
 
     /**
-     * Convenience operator to add to pager.
+     * Convenience operator to add to pager and auto-sort.
      * @param text to add to list.
      */
     inline void operator+=(const char *text)
@@ -333,6 +341,69 @@ public:
      */
     inline stringpager& operator<<(const char *text)
         {add(text); return *this;};
+
+    /**
+     * Sort members.
+     */
+    void sort(void);
+
+private:
+    member *last;
+};
+
+/**
+ * Directory pager is a paged string list for directory file names.
+ * This protocol is used to convert a directory into a list of filenames.
+ * As a protocol it offers a filtering method to select which files to
+ * include in the list.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+class __EXPORT DirPager : protected stringpager
+{
+protected:
+    const char *dir;
+
+    /**
+     * Filter filenames in a derived class.
+     * @param filename to filter.
+     * @return true if include in final list.
+     */
+    virtual bool filter(const char *filename);
+
+    /**
+     * Load a directory path.
+     * @param path to load.
+     * @return true if valid.
+     */
+    bool load(const char *path);
+
+public:
+    DirPager();
+
+    DirPager(const char *path);
+
+    void operator=(const char *path);
+
+    inline const char *operator*()
+        {return dir;};
+
+    inline operator bool()
+        {return dir != NULL;};
+
+    inline bool operator!()
+        {return dir == NULL;};
+
+    /**
+     * Return specified filename from directory list.  This is a convenience
+     * operator.
+     * @param item to access.
+     * @return text of item or NULL if invalid.
+     */
+    inline const char *operator[](unsigned item)
+        {return stringpager::get(item);};
+
+    inline const char *get(unsigned item)
+        {return stringpager::get(item);};
 };
 
 /**
@@ -847,6 +918,22 @@ public:
         {return NamedObject::sort(NamedObject::index(idx, M));};
 };
 
+/**
+ * A convenience type for paged string lists.
+ */
+typedef stringpager stringlist_t;
+
+/**
+ * A convenience type for paged string list items.
+ */
+typedef stringpager::member stringlistitem_t;
+
+/**
+ * A convenience type for using DirPager directly.
+ */
+typedef DirPager dirlist_t;
+
+
 END_NAMESPACE
 
 #endif
